==> pointpos_api-0.0.16.tar.gz: test/loyalty_program_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for LoyaltyProgramApi
void main() {
  var instance = new LoyaltyProgramApi();

  group('tests for LoyaltyProgramApi', () {
    // Create Loyaltyprogram
    //
    // Create Loyaltyprogram
    //
    //Future<LoyaltyProgram> createLoyaltyprogram(String authorization, String xAPIKey, LoyaltyProgram body, { String xPin }) async 
    test('test createLoyaltyprogram', () async {
      // TODO
    });

    // Delete Loyaltyprogram By ID
    //
    // Delete Loyaltyprogram By ID
    //
    //Future deleteLoyaltyprogramByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteLoyaltyprogramByID', () async {
      // TODO
    });

    // Get Loyaltyprogram List
    //
    // Get Loyaltyprogram  List
    //
    //Future<List<LoyaltyProgram>> findLoyaltyprogram(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findLoyaltyprogram', () async {
      // TODO
    });

    // Get Loyaltyprogram By ID
    //
    // Get Loyaltyprogram By ID
    //
    //Future<LoyaltyProgram> getLoyaltyprogramByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getLoyaltyprogramByID', () async {
      // TODO
    });

    // Update Loyaltyprogram By ID
    //
    // Update [object Object] By ID
    //
    //Future<LoyaltyProgram> updateLoyaltyprogramByID(String authorization, String xAPIKey, String id, LoyaltyProgram body, { String xPin }) async 
    test('test updateLoyaltyprogramByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/loyalty_program_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for LoyaltyProgramApi
void main() {
  var instance = new LoyaltyProgramApi();

  group('tests for LoyaltyProgramApi', () {
    // Create Loyaltyprogram
    //
    // Create Loyaltyprogram
    //
    //Future<LoyaltyProgram> createLoyaltyprogram(String authorization, String xAPIKey, LoyaltyProgram body, { String xPin }) async 
    test('test createLoyaltyprogram', () async {
      // TODO
    });

    // Delete Loyaltyprogram By ID
    //
    // Delete Loyaltyprogram By ID
    //
    //Future deleteLoyaltyprogramByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteLoyaltyprogramByID', () async {
      // TODO
    });

    // Get Loyaltyprogram List
    //
    // Get Loyaltyprogram  List
    //
    //Future<List<LoyaltyProgram>> findLoyaltyprogram(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findLoyaltyprogram', () async {
      // TODO
    });

    // Get Loyaltyprogram By ID
    //
    // Get Loyaltyprogram By ID
    //
    //Future<LoyaltyProgram> getLoyaltyprogramByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getLoyaltyprogramByID', () async {
      // TODO
    });

    // Update Loyaltyprogram By ID
    //
    // Update [object Object] By ID
    //
    //Future<LoyaltyProgram> updateLoyaltyprogramByID(String authorization, String xAPIKey, String id, LoyaltyProgram body, { String xPin }) async 
    test('test updateLoyaltyprogramByID', () async {
      // TODO
    });

  });
}
